@@ -7,7 +7,7 @@
 #  define VTKIOXML_NO_EXPORT
 #else
 #  ifndef VTKIOXML_EXPORT
-#    ifdef vtkIOXML_EXPORTS
+#    ifdef IOXML_EXPORTS
         /* We are building this library */
 #      define VTKIOXML_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKIOXML_DEPRECATED
 #  define VTKIOXML_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOXML_DEPRECATED_EXPORT VTKIOXML_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOXML_DEPRECATED_NO_EXPORT VTKIOXML_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOXML_NO_DEPRECATED
+#ifndef VTKIOXML_DEPRECATED_EXPORT
+#  define VTKIOXML_DEPRECATED_EXPORT VTKIOXML_EXPORT VTKIOXML_DEPRECATED
 #endif
 
-
-
+#ifndef VTKIOXML_DEPRECATED_NO_EXPORT
+#  define VTKIOXML_DEPRECATED_NO_EXPORT VTKIOXML_NO_EXPORT VTKIOXML_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOXML_NO_DEPRECATED
+#    define VTKIOXML_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkIOXMLModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKIOXML_EXPORT_H */
