@@ -7,7 +7,7 @@
 #  define VTKRENDERINGPARALLEL_NO_EXPORT
 #else
 #  ifndef VTKRENDERINGPARALLEL_EXPORT
-#    ifdef vtkRenderingParallel_EXPORTS
+#    ifdef RenderingParallel_EXPORTS
         /* We are building this library */
 #      define VTKRENDERINGPARALLEL_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,25 @@
 
 #ifndef VTKRENDERINGPARALLEL_DEPRECATED
 #  define VTKRENDERINGPARALLEL_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKRENDERINGPARALLEL_DEPRECATED_EXPORT VTKRENDERINGPARALLEL_EXPORT __attribute__ ((__deprecated__))
-#  define VTKRENDERINGPARALLEL_DEPRECATED_NO_EXPORT VTKRENDERINGPARALLEL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKRENDERINGPARALLEL_NO_DEPRECATED
+#ifndef VTKRENDERINGPARALLEL_DEPRECATED_EXPORT
+#  define VTKRENDERINGPARALLEL_DEPRECATED_EXPORT VTKRENDERINGPARALLEL_EXPORT VTKRENDERINGPARALLEL_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkRenderingCoreModule.h"
-#include "vtkRenderingOpenGL2Module.h"
-
+#ifndef VTKRENDERINGPARALLEL_DEPRECATED_NO_EXPORT
+#  define VTKRENDERINGPARALLEL_DEPRECATED_NO_EXPORT VTKRENDERINGPARALLEL_NO_EXPORT VTKRENDERINGPARALLEL_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKRENDERINGPARALLEL_NO_DEPRECATED
+#    define VTKRENDERINGPARALLEL_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkRenderingParallelModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKRENDERINGPARALLEL_EXPORT_H */
